@@ -2,7 +2,11 @@
 
 APP='FocusWriter'
 BUNDLE="$APP.app"
-VERSION='1.7.6'
+VERSION='1.8.2'
+
+# Locate deployment script
+BIN_DIR=$(pwd)
+cd $(dirname "${BASH_SOURCE[0]}")
 
 # Remove any previous disk folder or DMG
 echo -n 'Preparing... '
@@ -16,7 +20,7 @@ echo 'Done'
 # Create disk folder
 echo -n 'Copying application bundle... '
 mkdir "$APP"
-cp -Rf "$BUNDLE" "$APP/"
+cp -Rf "${BIN_DIR}/${BUNDLE}" "$APP/"
 strip "$APP/$BUNDLE/Contents/MacOS/$APP"
 cp COPYING "$APP/License.txt"
 echo 'Done'
@@ -38,15 +42,9 @@ echo >> "$APP/Read Me.txt"
 cat ChangeLog >> "$APP/Read Me.txt"
 echo 'Done'
 
-# Copy translations
-echo -n 'Copying translations... '
-TRANSLATIONS="$APP/$BUNDLE/Contents/Resources/translations"
-mkdir "$TRANSLATIONS"
-cp translations/*.qm "$TRANSLATIONS"
-echo 'Done'
-
 # Copy Qt translations
 echo -n 'Copying Qt translations... '
+TRANSLATIONS="$APP/$BUNDLE/Contents/Resources/translations"
 cp $QTDIR/translations/qt_* "$TRANSLATIONS"
 cp $QTDIR/translations/qtbase_* "$TRANSLATIONS"
 rm -f $TRANSLATIONS/qt_help_*
